import numpy as np


def norm(vector):
    norm = np.linalg.norm(vector, axis=-1, keepdims=True)
    return vector / norm


def dot_product(a, b):
    return b @ a.T


def cosine_similarity(a, b):
    a_norm = norm(a)
    b_norm = norm(b)
    return b_norm @ a_norm.T


def euclidean(a, b, use_similarity=True):
    distances = np.linalg.norm(a - b, axis=1)
    similarities = 1 / (1 + distances)
    return similarities if use_similarity else distances


OPSET_LOOKUP = {
    "dot": dot_product,
    "cosine": cosine_similarity,
    "euclidean": euclidean,
}



from setuptools import setup

with open("./README.md", "r") as f:
    long_desc = f.read()

setup(
    name="iotadb",
    version="0.0.4",
    description="An easy-to-use, lightweight local embedding database.",
    packages=["iotadb"],
    long_description=long_desc,
    long_description_content_type="text/markdown",
    url="https://github.com/timothyckl/iota",
    author="timothyckl",
    author_email="timothy.ckl@outlook.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Operating System :: OS Independent",
    ],
    install_requires=["numpy>=1.26.4", "sentence-transformers>=2.5.1"],
    extras_require={"dev": ["pytest>=8.1.1", "twine>=5.0.0"]},
    python_requires=">=3.5",
)
